% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/getExperimentCrossAssociation.R
\name{getExperimentCrossAssociation}
\alias{getExperimentCrossAssociation}
\alias{getExperimentCrossCorrelation}
\alias{getExperimentCrossAssociation,MultiAssayExperiment-method}
\alias{getExperimentCrossAssociation,SummarizedExperiment-method}
\alias{testExperimentCrossAssociation}
\alias{testExperimentCrossCorrelation}
\alias{testExperimentCrossAssociation,ANY-method}
\alias{testExperimentCrossCorrelation,ANY-method}
\alias{getExperimentCrossCorrelation,ANY-method}
\title{Calculate correlations between features of two experiments.}
\usage{
getExperimentCrossAssociation(x, ...)

\S4method{getExperimentCrossAssociation}{MultiAssayExperiment}(
  x,
  experiment1 = 1,
  experiment2 = 2,
  abund_values1 = "counts",
  abund_values2 = "counts",
  MARGIN = 1,
  method = c("spearman", "categorical", "kendall", "pearson"),
  mode = "table",
  p_adj_method = c("fdr", "BH", "bonferroni", "BY", "hochberg", "holm", "hommel",
    "none"),
  p_adj_threshold = NULL,
  cor_threshold = NULL,
  sort = FALSE,
  filter_self_correlations = FALSE,
  verbose = TRUE,
  test_significance = FALSE,
  show_warnings = TRUE,
  paired = FALSE,
  ...
)

\S4method{getExperimentCrossAssociation}{SummarizedExperiment}(x, experiment2 = x, ...)

testExperimentCrossAssociation(x, ...)

\S4method{testExperimentCrossAssociation}{ANY}(x, ...)

testExperimentCrossCorrelation(x, ...)

\S4method{testExperimentCrossCorrelation}{ANY}(x, ...)

getExperimentCrossCorrelation(x, ...)

\S4method{getExperimentCrossCorrelation}{ANY}(x, ...)
}
\arguments{
\item{x}{A
\code{\link[MultiAssayExperiment:MultiAssayExperiment-class]{MultiAssayExperiment}} or
\code{\link[SummarizedExperiment:SummarizedExperiment-class]{SummarizedExperiment}}
object.}

\item{...}{Additional arguments:
\itemize{
\item{\code{symmetric}}{ A single boolean value for specifying if
measure is symmetric or not. When \code{symmetric = TRUE}, associations
are calculated only for unique variable-pairs, and they are assigned to
corresponding variable-pair. This decreases the number of calculations in 2-fold
meaning faster execution. (By default: \code{symmetric = FALSE}) }
\item{\code{association_FUN}}{ A function that is used to calculate (dis-)similarity
between features. Function must take matrix as an input and give numeric
values as an output. Adjust \code{method} and other parameters correspondingly.
Supported functions are, for example, \code{stats::dist} and \code{vegan::vegdist}.}
}}

\item{experiment1}{A single character or numeric value for selecting the experiment 1
from \code{experiments(x)} of \code{MultiassayExperiment} object.
(By default: \code{experiment1 = 1})}

\item{experiment2}{A single character or numeric value for selecting the experiment 2
from\code{experiments(x)} of \code{MultiAssayExperiment} object or
\code{altExp(x)} of \code{SummarizedExperiment} object. Alternatively,
\code{experiment2} can also be \code{SE} object when \code{x} is \code{SE} object.
(By default: \code{experiment2 = 2} when \code{x} is \code{MAE} and
\code{experiment2 = x} when \code{x} is \code{SE})}

\item{abund_values1}{A single character value for selecting the
\code{\link[SummarizedExperiment:SummarizedExperiment-class]{assay}} of
experiment 1 to be transformed. (By default: \code{abund_values1 = "counts"})}

\item{abund_values2}{A single character value for selecting the
\code{\link[SummarizedExperiment:SummarizedExperiment-class]{assay}} of
experiment 2 to be transformed. (By default: \code{abund_values2 = "counts"})}

\item{MARGIN}{A single numeric value for selecting if association are calculated
row-wise / for features (1) or column-wise / for samples (2). Must be \code{1} or
\code{2}. (By default: \code{MARGIN = 1})}

\item{method}{A single character value for selecting association method
('kendall', pearson', or 'spearman' for continuous/numeric; 'categorical' for discrete)
(By default: \code{method = "spearman"})}

\item{mode}{A single character value for selecting output format
Available formats are  'table' and 'matrix'.  (By default: \code{mode = "table"})}

\item{p_adj_method}{A single character value for selecting adjustment method of
p-values. Passed to \code{p.adjust} function.
(By default: \code{p_adj_method = "fdr"})}

\item{p_adj_threshold}{A single numeric value (from 0 to  1) for selecting
adjusted p-value threshold for filtering.
(By default: \code{p_adj_threshold = NULL})}

\item{cor_threshold}{A single numeric absolute value (from 0 to 1) for selecting
correlation threshold for filtering.
(By default: \code{cor_threshold = NULL})}

\item{sort}{A single boolean value for selecting whether to sort features or not
in result matrices. Used method is hierarchical clustering.
(By default: \code{sort = FALSE})}

\item{filter_self_correlations}{A single boolean value for selecting whether to
filter out correlations between identical items. Applies only when correlation
between experiment itself is tested, i.e., when assays are identical.
(By default: \code{filter_self_correlations = FALSE})}

\item{verbose}{A single boolean value for selecting whether to get messages
about progress of calculation.}

\item{test_significance}{A single boolean value for selecting whether to test
statistical significance of associations.}

\item{show_warnings}{A single boolean value for selecting whether to show warnings
that might occur when correlations and p-values are calculated.}

\item{paired}{A single boolean value for specifying if samples are paired or not.
\code{colnames} must match between twp experiments. \code{paired} is disabled
when \code{MARGIN = 1}. (By default: \code{paired = FALSE})}
}
\value{
These functions return associations in table or matrix format. In table format,
returned value is a data frame that includes  features and associations
(and p-values) in columns. In matrix format, returned value is a one matrix
when only associations are calculated. If also significances are tested, then
returned value is a list of matrices.
}
\description{
Calculate correlations between features of two experiments.
}
\details{
These functions calculates associations between features of two experiments.
\code{getExperimentCrossAssociation} calculates only associations by default.
\code{testExperimentCrossAssociation} calculates also significance of
associations.
}
\examples{
mae <- microbiomeDataSets::peerj32()

# Subset so that less observations / quicker to run, just for example
mae[[1]] <- mae[[1]][1:20, 1:10]
mae[[2]] <- mae[[2]][1:20, 1:10]
# Transform data
mae[[1]] <- transformSamples(mae[[1]], method = "rclr")

# Calculate cross-correlations
result <- getExperimentCrossAssociation(mae, method = "pearson")
# Show first 5 entries
head(result, 5)

# Same can be done with SummarizedExperiment and altExp
# Create TreeSE with altExp
tse <- mae[[1]]
altExp(tse, "exp2") <- mae[[2]]

# When mode = matrix, matrix is returned
result <- getExperimentCrossAssociation(tse, experiment2 = "exp2", 
                                        abund_values1 = "rclr", abund_values2 = "counts",
                                        method = "pearson", mode = "matrix")
# Show first 5 entries
head(result, 5)

# testExperimentCorrelation returns also significances
# filter_self_correlations = TRUE filters self correlations
# With p_adj_threshold it is possible to filter those features that do no have
# any correlations that have p-value under threshold
result <- testExperimentCrossAssociation(tse, experiment2 = tse, method = "pearson",
                                         filter_self_correlations = TRUE,
                                         p_adj_threshold = 0.05)
# Show first 5 entries
head(result, 5)

# Also getExperimentCrossAssociation returns significances when 
# test_signicance = TRUE
# Warnings can be suppressed by using show_warnings = FALSE
result <- getExperimentCrossAssociation(mae[[1]], experiment2 = mae[[2]], method = "pearson",
                                        mode = "matrix", test_significance = TRUE,
                                        show_warnings = FALSE)
                                        
# Returned value is a list of matrices
names(result)

# Calculate Bray-Curtis dissimilarity between samples. If dataset includes
# paired samples, you can use paired = TRUE.
result <- getExperimentCrossAssociation(mae[[1]], mae[[2]], MARGIN = 2, paired = FALSE,
                                        association_FUN = vegan::vegdist, method = "bray")
                                        

# If experiments are equal and measure is symmetric (e.g., taxa1 vs taxa2 == taxa2 vs taxa1),
# it is possible to speed-up calculations by calculating association only for unique
# variable-pairs. Use "symmetric" to choose whether to measure association for only
# other half of of variable-pairs.
result <- getExperimentCrossAssociation(mae, experiment1 = "microbiome", experiment2 = "microbiome", 
                                        abund_values1 = "counts", abund_values2 = "counts",
                                        symmetric = TRUE)

# For big data sets, calculation might take long. To make calculations quicker, you can take
# a random sample from data. In a complex biological problems, random sample
# can describe the data enough. Here our random sample is 30 \% of whole data.
sample_size <- 0.3
tse_sub <- tse[ sample( seq_len( nrow(tse) ), sample_size * nrow(tse) ), ]
result <- testExperimentCrossAssociation(tse_sub)
                                         
                                        
}
\author{
Leo Lahti and Tuomas Borman. Contact: \url{microbiome.github.io}
}
